import javax.vecmath.Color3f;

/**
 * A class representing the medium through which a traced ray travels when not
 * inside an object.
 */
public class Air implements Persistent
{
	/**
	 * Constructs an {@code Air} object with electric permittivity of 1.0,
	 * magnetic permeability of 1.0, and attenuation (1.0, 1.0, 1.0).
	 */
	public Air()
	{
		setElectricPermittivity( 1.0 );
		setMagneticPermeability( 1.0 );
		setAttenuation( new Color3f( 1.0f, 1.0f, 1.0f ) );
	}
	
	/**
	 * Performs a deep copy of the specified {@code Air} object.
	 * 
	 * @param air
	 * 			The {@code Air} object to copy.
	 */
	protected Air( Air air )
	{
		setElectricPermittivity( air.getElectricPermittivity() );
		setMagneticPermeability( air.getMagneticPermeability() );
		setAttenuation( (Color3f)air.getAttenuation().clone() );
	}

	@Override
	public Object clone()
	{
		return new Air( this );
	}

	public void load( DataParser dataParser )
	{
		setElectricPermittivity( dataParser.getDouble() );
		setMagneticPermeability( dataParser.getDouble() );
		setAttenuation( dataParser.getColor3f() );
	}

	/**
	 * Sets the electric permittivity of the medium.
	 * 
	 * @param electricPermittivity
	 *            The electric permittivity to set.
	 */
	public void setElectricPermittivity( double electricPermittivity )
	{
		this.electricPermittivity = electricPermittivity;
	}

	/**
	 * Returns the electric permittivity of the medium.
	 * 
	 * @return The electric permittivity.
	 */
	public double getElectricPermittivity()
	{
		return electricPermittivity;
	}

	/**
	 * Sets the magnetic permeability of the medium.
	 * 
	 * @param magneticPermeability
	 *            The magnetic permeability to set.
	 */
	public void setMagneticPermeability( double magneticPermeability )
	{
		this.magneticPermeability = magneticPermeability;
	}

	/**
	 * Returns the magnetic permeability of the medium.
	 * 
	 * @return The magnetic permeability.
	 */
	public double getMagneticPermeability()
	{
		return magneticPermeability;
	}

	/**
	 * Sets the attentuation of the medium.
	 * 
	 * @param attenuation
	 *            The attenuation to set.
	 */
	public void setAttenuation( Color3f attenuation )
	{
		this.attenuation = attenuation;
	}

	/**
	 * Returns the attenuation of the medium.
	 * 
	 * @return The attenuation.
	 */
	public Color3f getAttenuation()
	{
		return attenuation;
	}

	private double electricPermittivity;
	private double magneticPermeability;
	private Color3f attenuation;
}
