/**
 * A simple timer to gauge elapsed time.
 */
public class SystemTimer
{
	/**
	 * Begins or resets the timer.
	 */
	public void start()
	{
		startTime = System.nanoTime();
	}

	/**
	 * Returns the elapsed time since the last {@code start} call in seconds.
	 * 
	 * @return
	 * 			The number of seconds since the last call to {@code start}.
	 */
	public double getDuration()
	{
		long nanosElapsed = System.nanoTime() - startTime;
		return (double)nanosElapsed / 1.0e9;
	}
	
	/**
	 * Returns a string representing the duration of time since the {@code start}
	 * method was called in the format "HH:MM:SS".
	 */
	@Override
	public String toString()
	{
		double duration = getDuration();
		int hours	= (int) ( duration / (60.0 * 60.0) );
		int minutes = (int) ( duration / 60.0 ) % 60;
		int seconds = (int) ( duration % 60 );	
		
		return String.format( "%d:%02d:%02d", hours, minutes, seconds );
	}

	private long startTime;
}